summaryrefslogtreecommitdiff
path: root/chromium/components/autofill/core/browser/suggestion.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/components/autofill/core/browser/suggestion.h')
-rw-r--r--chromium/components/autofill/core/browser/suggestion.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/chromium/components/autofill/core/browser/suggestion.h b/chromium/components/autofill/core/browser/suggestion.h
index 63522debfec..7c65c4750b6 100644
--- a/chromium/components/autofill/core/browser/suggestion.h
+++ b/chromium/components/autofill/core/browser/suggestion.h
@@ -8,6 +8,7 @@
#include <string>
#include "base/strings/string16.h"
+#include "ui/gfx/image/image.h"
namespace autofill {
@@ -45,9 +46,12 @@ struct Suggestion {
base::string16 value;
base::string16 label;
+ // Contains an image to display for the suggestion.
+ gfx::Image custom_icon;
+ // If |custom_icon| is empty, the name of the fallback built-in icon.
base::string16 icon;
MatchMode match;
- bool is_value_bold; // true if |value| should be displayed in bold type face.
+ bool is_value_secondary; // |value| should be displayed as secondary text.
};
} // namespace autofill